<!-- some styles are removed because they are not extractable from the source files -->
<!-- add them here -->
<span class="
    text-red-500
    italic
    flex
    flex-row
    justify-content
    gap-2
"></span>
