{% autoescape off %}
You've asked to reset your password for the {{ site_name }} account associated with this email address ({{  user.get_username }}).
To get the password reset code, please click on the following link:
{% block reset_link %}
{{ protocol }}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}
{% endblock %}

You can also copy and paste the link above into a new browser window.


This password change code will expire 6 hours from the time this email was sent. To re-start the password change process, click here:
{{ protocol }}://{{ domain }}{% url "password_reset" %}

If you didn't make the request, you can ignore this email and do nothing.
Another user likely entered your email address by mistake while trying to reset a password.


Replies to this email are not monitored or answered.
For FAQs please visit {{ protocol }}://{{ domain }}{% url "faq" %} or to reach our help desk please visit {{ protocol }}://{{ domain }}{% url "contact" %}


Thank you for using {{ site_name }}.
The {{ site_name }} Team



***This is an automatic notification. Replies to this email are not monitored or answered.
{% endautoescape %}